@@ -14,7 +14,9 @@ class OrganizationBillingConfiguration(BaseModel):
 
 class Organization(BaseModel):
     webhook_url: Optional[str]
+    webhook_urls: Optional[List[str]]
     country: Optional[str]
+    default_currency: str
     address_line1: Optional[str]
     address_line2: Optional[str]
     state: Optional[str]
@@ -23,6 +25,9 @@ class Organization(BaseModel):
     city: Optional[str]
     legal_name: Optional[str]
     legal_number: Optional[str]
+    document_numbering: Optional[str]
+    document_number_prefix: Optional[str]
+    net_payment_term: Optional[int]
     tax_identification_number: Optional[str]
     timezone: Optional[str]
     email_settings: Optional[List[str]]
@@ -33,6 +38,7 @@ class OrganizationResponse(BaseResponseModel):
     name: str
     created_at: str
     webhook_url: Optional[str]
+    webhook_urls: Optional[List[str]]
     country: Optional[str]
     address_line1: Optional[str]
     address_line2: Optional[str]
@@ -42,6 +48,9 @@ class OrganizationResponse(BaseResponseModel):
     city: Optional[str]
     legal_name: Optional[str]
     legal_number: Optional[str]
+    net_payment_term: Optional[int]
+    document_numbering: Optional[str]
+    document_number_prefix: Optional[str]
     tax_identification_number: Optional[str]
     timezone: Optional[str]
     email_settings: Optional[List[str]]
